summaryrefslogtreecommitdiffstats
path: root/lib/libc/gen/strtofflags.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libc/gen/strtofflags.c')
-rw-r--r--lib/libc/gen/strtofflags.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/libc/gen/strtofflags.c b/lib/libc/gen/strtofflags.c
index c1fe6c5..2cf6f39 100644
--- a/lib/libc/gen/strtofflags.c
+++ b/lib/libc/gen/strtofflags.c
@@ -74,12 +74,12 @@ static struct {
#define nmappings (sizeof(mapping) / sizeof(mapping[0]))
/*
* getflags --
* Convert stat flags to a comma-separated string. If no flags
* are set, return the default string.
*/
char *
-getflags(flags, def)
+fflagstostr(flags, def)
u_long flags;
char *def;
{
@@ -104,13 +104,13 @@ getflags(flags, def)
}
/*
* setflags --
* Take string of arguments and return stat flags. Return 0 on
* success, 1 on failure. On failure, stringp is set to point
* to the offending token.
*/
int
-setflags(stringp, setp, clrp)
+strtofflags(stringp, setp, clrp)
char **stringp;
u_long *setp, *clrp;
{
@@ -74,12 +74,12 @@ static struct {
#define nmappings (sizeof(mapping) / sizeof(mapping[0]))
/*
- * getflags --
- * Convert stat flags to a comma-separated string. If no flags
+ * fflagstostr --
+ * Convert file flags to a comma-separated string. If no flags
* are set, return the default string.
*/
@@ -104,13 +104,13 @@ getflags(flags, def)
}
/*
- * setflags --
- * Take string of arguments and return stat flags. Return 0 on
+ * strtofflags --
+ * Take string of arguments and return file flags. Return 0 on
* success, 1 on failure. On failure, stringp is set to point
* to the offending token.
OpenPOWER on IntegriCloud